containertools.remove_empty_containers_in_expr
==============================================

.. autofunction:: abjad.tools.containertools.remove_empty_containers_in_expr.remove_empty_containers_in_expr
